SystemOrganization addCategory: #ConfigurationOfZTimestamp!

Object subclass: #ConfigurationOfZTimestamp
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfZTimestamp'!

!ConfigurationOfZTimestamp commentStamp: 'SvenVanCaekenberghe 2/1/2014 17:23' prior: 0!
I am ConfigurationOfZTimestamp, a Metacello configuration to load ZTimestamp.

ZTimestamp, a Magnitude, represents a point in time, a combination of a date and a time.
It is an alternative for DateAndTime and TimeStamp.
It has second precision and lives in the UTC/GMT/Zulu timezone.
It uses ISO/International conventions and protocols only. 
ZTimestamp is more efficient: it uses half the memory of DateAndTime and is faster.

Also contains  ZTimestampFormat, a 'by example' formatter/parser for DateAndTime, TimeStamp, Date, Time and ZTimestamp and ZTimestampSNTPClient, a simple SNTP client to check your local clock.!

!ConfigurationOfZTimestamp class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfZTimestamp class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfZTimestamp class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 3/12/2014 13:36'!
catalogChangeLog
	"Returns a paragraph describing the most important changes in the configuration class."
	^ 'Started April 2012 with core ZTimestamp as alternative to DateAndTime/Timestamp. Added ZTimestampFormat to format/parse by example in November 2012. Added SNTP client in February 2013. Added ZTimezone support in March 2014'! !

!ConfigurationOfZTimestamp class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 3/12/2014 13:29'!
catalogContactInfo
	"Returns a paragraph describing contact information such as email, mailing lists and website."
	^ 'Written and maintained by Sven Van Caekenberghe (http://stfx.eu). Discussions on the Pharo aling lists. Documentation can be found at https://github.com/svenvc/docs/blob/master/neo/ztimestamp.md'! !

!ConfigurationOfZTimestamp class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 3/12/2014 13:46'!
catalogDescription
	"Returns a paragraph describing the project"
	^ 'The ZTimestamp project groups a number of classes that form an addition/alternative to DateAndTime/Timestamp. The core ZTimestamp class represents a point in time, with second precision and always in the UTC/GTM/Zulu timezone. It is faster and smaller. ZTimestampFormat is a formatter and parser that is example based. ZTimezone uses the standard Olsone timezone database to compute the offset for local time at specific points in time for a specified timezone. ZTimestampSNTPClient is an SNTP client to check the local clock against network time servers. This project is small and has no further dependencies. It runs in Pharo 2 and 3.'! !

!ConfigurationOfZTimestamp class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 3/12/2014 13:26'!
catalogKeyClassesAndExample
	"Returns a paragraph or more describing the key classes of your project. You can use Pillar/Pier syntax to layout out the text i.e., ==Code== and - for bullet."
	^ 'The core classes are ZTimestamp to represent a point in time, ZTimestampFormat to format and parse chronology objects by example, ZTimezone to compute local time offsets and ZTimestampSNTPClient to check the clock against an network time server.'! !

!ConfigurationOfZTimestamp class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 3/12/2014 13:27'!
catalogKeywords
	"Returns an array of symbols"
	^ #(timestamp time date chronology parsing formatting timezone sntp) ! !

!ConfigurationOfZTimestamp class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfZTimestamp class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfZTimestamp class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfZTimestamp class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfZTimestamp class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfZTimestamp class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfZTimestamp class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
project

	^self new project! !

!ConfigurationOfZTimestamp class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfZTimestamp methodsFor: 'baselines' stamp: 'SvenVanCaekenberghe 6/22/2012 15:10'!
baseline1: spec
	<version: '1-baseline'>
	
	spec for: #common do: [
		spec 
			blessing: #baseline;
			repository: 'http://mc.stfx.eu/Neo';
			package: 'ZTimestamp' ]! !

!ConfigurationOfZTimestamp methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/22/2012 14:57'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfZTimestamp methodsFor: 'symbolic versions' stamp: 'SvenVanCaekenberghe 2/12/2014 14:58'!
stable: spec
	<symbolicVersion: #'stable'>
	
	spec for: #common version: '15'! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 5/31/2013 09:40'!
version10: spec
	<version: '10' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.29' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 6/21/2013 21:09'!
version11: spec
	<version: '11' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.30' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 6/27/2013 14:11'!
version12: spec
	<version: '12' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.31' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 2/1/2014 13:28'!
version13: spec
	<version: '13' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.32' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 2/1/2014 17:19'!
version14: spec
	<version: '14' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.33' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 2/12/2014 14:58'!
version15: spec
	<version: '15' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.34' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:14'!
version1: spec
	<version: '1' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.11' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:14'!
version2: spec
	<version: '2' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.12' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 9/27/2012 20:14'!
version3: spec
	<version: '3' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.15' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 10/12/2012 13:15'!
version4: spec
	<version: '4' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.16' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 11/5/2012 20:08'!
version5: spec
	<version: '5' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.19' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 11/5/2012 21:25'!
version6: spec
	<version: '6' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.20' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 12/19/2012 13:53'!
version7: spec
	<version: '8' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.22' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 5/29/2013 17:22'!
version8: spec
	<version: '8' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.28' ]! !

!ConfigurationOfZTimestamp methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 5/29/2013 17:23'!
version9: spec
	<version: '9' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'ZTimestamp' with: 'ZTimestamp-SvenVanCaekenberghe.28' ]! !
